"""DiffSync model class definitions for nautobot-netbox-importer.

Note that in most cases the same model classes are used for both NetBox imports and Nautobot exports.
Because this plugin is meant *only* for NetBox-to-Nautobot migration, the create/update/delete methods on these classes
are for populating data into Nautobot only, never the reverse.
"""

from .auth import Group, Permission
from .contenttypes import ContentType
from .circuits import Provider, Circuit, CircuitTermination, CircuitType
from .dcim import (
    Cable,
    # TODO do we need CablePath, or just let it be rebuilt automatically?
    ConsolePort,
    ConsolePortTemplate,
    ConsoleServerPort,
    ConsoleServerPortTemplate,
    Device,
    DeviceBay,
    DeviceBayTemplate,
    DeviceRole,
    DeviceType,
    FrontPort,
    FrontPortTemplate,
    Interface,
    InterfaceTemplate,
    InventoryItem,
    Manufacturer,
    Platform,
    PowerFeed,
    PowerOutlet,
    PowerOutletTemplate,
    PowerPanel,
    PowerPort,
    PowerPortTemplate,
    Rack,
    RackGroup,
    RackReservation,
    RackRole,
    RearPort,
    RearPortTemplate,
    Region,
    Site,
    VirtualChassis,
)
from .extras import (
    ConfigContext,
    CustomField,
    CustomFieldChoice,
    CustomLink,
    ExportTemplate,
    JobResult,
    Status,
    Tag,
    TaggedItem,
    Webhook,
)
from .ipam import (
    Aggregate,
    IPAddress,
    Prefix,
    RIR,
    Role,
    RouteTarget,
    Service,
    VLAN,
    VLANGroup,
    VRF,
)
from .tenancy import Tenant, TenantGroup
from .users import ObjectPermission, Token, User
from .virtualization import Cluster, ClusterGroup, ClusterType, VirtualMachine, VMInterface

__all__ = (
    "Aggregate",
    "Cable",
    "Circuit",
    "CircuitTermination",
    "CircuitType",
    "Cluster",
    "ClusterGroup",
    "ClusterType",
    "ConfigContext",
    "ConsolePort",
    "ConsolePortTemplate",
    "ConsoleServerPort",
    "ConsoleServerPortTemplate",
    "ContentType",
    "CustomField",
    "CustomFieldChoice",
    "CustomLink",
    "Device",
    "DeviceBay",
    "DeviceBayTemplate",
    "DeviceRole",
    "DeviceType",
    "ExportTemplate",
    "FrontPort",
    "FrontPortTemplate",
    "Group",
    "Interface",
    "InterfaceTemplate",
    "InventoryItem",
    "IPAddress",
    "JobResult",
    "Manufacturer",
    "ObjectPermission",
    "Permission",
    "Platform",
    "PowerFeed",
    "PowerOutlet",
    "PowerOutletTemplate",
    "PowerPanel",
    "PowerPort",
    "PowerPortTemplate",
    "Prefix",
    "Provider",
    "Rack",
    "RackGroup",
    "RackReservation",
    "RackRole",
    "RearPort",
    "RearPortTemplate",
    "Region",
    "RIR",
    "Role",
    "RouteTarget",
    "Service",
    "Site",
    "Status",
    "Tag",
    "TaggedItem",
    "Tenant",
    "TenantGroup",
    "Token",
    "User",
    "VirtualChassis",
    "VirtualMachine",
    "VLAN",
    "VLANGroup",
    "VMInterface",
    "VRF",
    "Webhook",
)
